#ifndef GETFHTML_H
#define GETFHTML_H

/* 27 March 2021, by Ruud Harmsen */

/* gfh_GetFromBuff expects a null-terminated buffer `buff'
   containing HTML-code. It parses the code using Google's
   gumbo-parser (see https://github.com/google/gumbo-parser).
   It then find the first occurrence of tag `tagname'.

   If `attrname' is NULL, or a pointer to an empty string,
   gfh_GetFromBuff returns the text child belonging to `tagname'.
   This is useful for example to extract the title from an
   HTML buffer.

   If `attrname' points to a non-empty string, gfh_GetFromBuff
   finds the first attribute of that name under `tagname', and
   returns the corresponding value. This is useful for example
   to find the language code specified as "<html lang=en>" or
   similar.

   Both `tagname' and `attrname' are case-insensitive.

   The return value is a pointer to a malloc'ed area, and it
   is up to the caller to free that.
   The return value is NULL if no result could be found.
 */
char *gfh_GetFromBuff (char *buff, char *tagname, char *attrname);

/* gfh_GetFromHtml is similar to gfh_GetFromBuff except that
   it operates on a file instead of a buffer. It will read
   at most nbytes (not including the closing null-byte) from
   the file into an internal buffer, and call gfh_GetFromBuff
   on that buffer.

   If nbytes is zero, it means the whole file will read into
   memory and parsed.
 */
#include <stdio.h>
char *gfh_GetFromHtml (FILE *htmlfile, size_t nbytes, char *tagname, char *attrname);

/* And the same again, now from a file pathname, null-terminated */
char *gfh_GetFromPath (char *path, size_t nbytes, char *tagname, char *attrname);

#endif
